@@ -1,4 +1,3 @@
-from sys import stdout
 from pytorch_lightning.callbacks import ProgressBarBase
 
 
@@ -6,7 +5,6 @@ class PrintProgressBar(ProgressBarBase):
     """
     仅输出文本信息的进度条
     """
-
     def __init__(self):
         self.train_batch_id = 0
         self.val_batch_id = 0
@@ -17,53 +15,60 @@ class PrintProgressBar(ProgressBarBase):
 
     def on_train_batch_end(self, trainer, pl_module, outputs, batch, batch_idx, dataloader_idx):
         self.train_batch_id = batch_idx + 1
-        stdout.write(f"{self.get_info('train', trainer)}\r")
-        stdout.flush()
+        progress, stage, info = self.get_info(trainer, 'train', 'step')
+        print(f"{progress} {stage} {info}", end="\r", flush=True)
 
     def on_train_epoch_end(self, trainer, pl_module, outputs):
-        print(self.get_info('train', trainer))
+        progress, train_stage, train_info = self.get_info(trainer, 'train', 'epoch')
+        _, val_stage, val_info = self.get_info(trainer, 'val', 'epoch')
+        print(progress, train_stage, train_info, val_stage, val_info)
 
     def on_validation_batch_end(self, trainer, pl_module, outputs, batch, batch_idx, dataloader_idx):
         self.val_batch_id = batch_idx + 1
-        stdout.write(f"{self.get_info('val', trainer)}\r")
-        stdout.flush()
-
-    def on_validation_epoch_end(self, trainer, pl_module):
-        print(self.get_info('val', trainer))
+        progress, stage, info = self.get_info(trainer, 'val', 'step')
+        print(f"{progress} {stage} {info}", end="\r", flush=True)
 
     def on_test_epoch_start(self, trainer, pl_module):
-        print('-' * 10)
+        print('-' * 23)
 
     def on_test_batch_end(self, trainer, pl_module, outputs, batch, batch_idx, dataloader_idx):
         self.test_batch_id = batch_idx + 1
-        stdout.write(f"{self.get_info('test', trainer)}\r")
-        stdout.flush()
+        progress, stage, info = self.get_info(trainer, 'test', 'step')
+        print(f"{progress} {stage} {info}", end="\r", flush=True)
 
     def on_test_epoch_end(self, trainer, pl_module):
-        print(self.get_info('test', trainer))
+        progress, stage, info = self.get_info(trainer, 'test', 'epoch')
+        print(progress, stage, info)
 
-    def get_info(self, stage, trainer):
+    def get_info(self, trainer, stage, unit):
+        """get training, validation or testing output infomation from Trainer by stage and unit.
+
+        Args:
+            trainer (Trainer): Trainer.
+            stage (str): 'train', 'val' or 'test'.
+            unit (str): 'step' or 'epoch'.
+
+        Returns:
+            [str, str, str]: stage str, progress str, information str
+        """
         info = trainer.progress_bar_dict
-        info_str = ' | '.join([f'{self._key(k):>8}: {str(v)[:7]:7}' for k, v in info.items() if self._check_info(stage, k)])
+        info_str = '  '.join([f'{self._key(k):>}: {v:0<6.4f}' for k, v in info.items() if self._check_info(k, stage, unit)])
         if stage == 'train':
-            stage = 'TRAIN'
+            stage = 'TRAIN >'
             c_batch = self.train_batch_id
             num_batch = trainer.num_training_batches
-            loss_str = f'T_loss: {str(info.get("loss","nan"))[:6]:6}'
         elif stage == 'val':
-            stage = ' VAL '
+            stage = '  VAL >'
             c_batch = self.val_batch_id
             num_batch = self._total_val_batches(trainer)
-            loss_str = f'V_loss: {str(info.get("val_loss", "nan"))[:6]:6}'
         else:
-            stage = ' TST '
+            stage = ' TEST >'
             c_batch = self.test_batch_id
             num_batch = sum(trainer.num_test_batches)
-            loss_str = f'  loss: {str(info.get("test_loss", "nan"))[:6]:6}'
         c_epoch = trainer.current_epoch + 1
         max_epoch = trainer.max_epochs
 
-        return f"E:{c_epoch:>3}/{max_epoch:<3}|{stage}| B:{c_batch:>4}/{num_batch:<4} | {loss_str} | {info_str}"
+        return f"E:{c_epoch:>3d}/{max_epoch:<3d} B:{c_batch:>4d}/{num_batch:<4d}", f"| {stage}", f"{info_str}"
 
     def _total_val_batches(self, trainer):
         total_val_batches = 0
@@ -72,12 +77,11 @@ class PrintProgressBar(ProgressBarBase):
         return total_val_batches
 
     def _key(self, k):
-        return k.replace('step', 's').replace('epoch', 'e').replace('train', 'T').replace('val', 'V').replace('test_', '')
+        return k.replace('_step', '').replace('_epoch', '').replace('train_', '').replace('val_', '').replace('test_', '')
 
-    def _check_info(self, stage, info_key):
-        if info_key[-4:] == 'loss':
-            return False
-        if info_key.split('_')[0] != stage:
+    def _check_info(self, info_key, stage, unit):
+        key_split = info_key.split('_')
+        if key_split[0] != stage or key_split[-1]!=unit:
             return False
         else:
             return True
